==> cloud-4.0.0-beta1.tar.gz: cloud/modules/cloud_service_providers/aws_cloud/src/Form/Ec2/ImageDeleteForm.php <==
<?php

namespace Drupal\aws_cloud\Form\Ec2;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\StringTranslation\TranslatableMarkup;

/**
 * Provides a form for deleting a Image entity.
 *
 * @ingroup aws_cloud
 */
class ImageDeleteForm extends AwsDeleteUpdateEntityForm {

  /**
   * {@inheritdoc}
   */
  public function getDescription(): TranslatableMarkup {
    $state = $this->entity->getStatus();
    if ($state === 'pending') {
      return $this->t("Cannot delete an image in @state state.", [
        '@state' => $state,
      ]);
    }
    return parent::getDescription();
  }

  /**
   * {@inheritdoc}
   */
  public function getQuestion(): ?TranslatableMarkup {
    if ($this->entity->getStatus() === 'pending') {
      return NULL;
    }
    return parent::getQuestion();
  }

  /**
   * {@inheritdoc}
   */
  protected function actions(array $form, FormStateInterface $form_state): array {
    $actions = parent::actions($form, $form_state);
    if ($this->entity->getStatus() === 'pending') {
      unset($actions['submit']);
    }
    return $actions;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {

    $entity = $this->entity;
    if ($entity->getEntityTypeId() === 'aws_cloud_image'
        && !$this->updateEntitySubmitForm($form_state, $entity)) {
      return;
    }

    $this->ec2Service->setCloudContext($entity->getCloudContext());
    $this->cloudConfigPluginManager->setCloudContext($entity->getCloudContext());
    $account_id = $this->cloudConfigPluginManager->loadConfigEntity()->get('field_account_id')->value;

    // If the image isn't owned by the aws user,
    // the calling for deregisterImage will be skipped for AWS Cloud
    // and it will be called for OpenStack.
    if (($entity->getEntityTypeId() === 'aws_cloud_image'
    && ($entity->getAccountId() !== $account_id))
    || $this->ec2Service->deregisterImage([
      'ImageId' => $entity->getImageId(),
    ]) !== NULL) {

      $entity->delete();

      // Don't change the following message since we cannot use
      // $entity->label(), which represents 'ami_name'.
      $this->messenger->addStatus($this->t('The @type @label has been deleted.', [
        '@type'  => $entity->getEntityType()->getSingularLabel(),
        '@label' => $entity->getName(),
      ]));
      $this->logDeletionMessage();
      $this->clearCacheValues($entity->getCacheTags());
      $this->dispatchSubmitEvent($entity);
    }
    else {

      // Don't change the following message since we cannot use
      // $entity->label(), which represents 'ami_name'.
      $this->messenger->addError($this->t('The @type @label could not be deleted.', [
        '@type'  => $entity->getEntityType()->getSingularLabel(),
        '@label' => $entity->getName(),
      ]));

      $this->logger($entity->getEntityType()->getProvider())->error($this->t('@type: @label could not be deleted.', [
        '@type' => $entity->getEntityType()->getLabel(),
        '@label' => $entity->label(),
      ]), [
        'link' => $entity->toLink($this->t('View'))->toString(),
      ]);
    }

    $form_state->setRedirect("view.{$entity->getEntityTypeId()}.list", ['cloud_context' => $entity->getCloudContext()]);
  }

}

==> cloud-5.0.0-beta1.tar.gz: cloud/modules/cloud_service_providers/aws_cloud/src/Form/Ec2/ImageDeleteForm.php <==
<?php

namespace Drupal\aws_cloud\Form\Ec2;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\StringTranslation\TranslatableMarkup;

/**
 * Provides a form for deleting a Image entity.
 *
 * @ingroup aws_cloud
 */
class ImageDeleteForm extends AwsDeleteUpdateEntityForm {

  /**
   * {@inheritdoc}
   */
  public function getDescription(): TranslatableMarkup {
    $state = $this->entity->getStatus();
    if ($state === 'pending') {
      return $this->t("Cannot delete an image in @state state.", [
        '@state' => $state,
      ]);
    }
    return parent::getDescription();
  }

  /**
   * {@inheritdoc}
   */
  public function getQuestion(): ?TranslatableMarkup {
    if ($this->entity->getStatus() === 'pending') {
      return NULL;
    }
    return parent::getQuestion();
  }

  /**
   * {@inheritdoc}
   */
  protected function actions(array $form, FormStateInterface $form_state): array {
    $actions = parent::actions($form, $form_state);
    if ($this->entity->getStatus() === 'pending') {
      unset($actions['submit']);
    }
    return $actions;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {

    $entity = $this->entity;
    if ($entity->getEntityTypeId() === 'aws_cloud_image'
        && !$this->updateEntitySubmitForm($form_state, $entity)) {
      return;
    }

    $this->ec2Service->setCloudContext($entity->getCloudContext());
    $this->cloudConfigPluginManager->setCloudContext($entity->getCloudContext());
    $account_id = $this->cloudConfigPluginManager->loadConfigEntity()->get('field_account_id')->value;

    // If the image is not owned by the aws user,
    // the calling for deregisterImage will be skipped for AWS Cloud
    // and it will be called for OpenStack.
    if (($entity->getEntityTypeId() === 'aws_cloud_image'
    && ($entity->getAccountId() !== $account_id))
    || ($result = $this->ec2Service->deregisterImage([
      'ImageId' => $entity->getImageId(),
    ])) !== NULL) {

      if (!empty($result['SendToWorker'])) {
        $this->messenger->addStatus($this->t('The @type @label has been deleted remotely.', [
          '@type'  => $entity->getEntityType()->getSingularLabel(),
          '@label' => $entity->getName(),
        ]));

        $form_state->setRedirect("view.{$entity->getEntityTypeId()}.list", ['cloud_context' => $entity->getCloudContext()]);
        return;
      }

      $entity->delete();

      // Do not change the following message since we cannot use
      // $entity->label(), which represents 'ami_name'.
      $this->messenger->addStatus($this->t('The @type @label has been deleted.', [
        '@type'  => $entity->getEntityType()->getSingularLabel(),
        '@label' => $entity->getName(),
      ]));
      $this->logDeletionMessage();
      $this->clearCacheValues($entity->getCacheTags());
      $this->dispatchSubmitEvent($entity);
    }
    else {

      // Do not change the following message since we cannot use
      // $entity->label(), which represents 'ami_name'.
      $this->messenger->addError($this->t('The @type @label could not be deleted.', [
        '@type'  => $entity->getEntityType()->getSingularLabel(),
        '@label' => $entity->getName(),
      ]));

      $this->logger($entity->getEntityType()->getProvider())->error($this->t('@type: @label could not be deleted.', [
        '@type' => $entity->getEntityType()->getLabel(),
        '@label' => $entity->label(),
      ]), [
        'link' => $entity->toLink($this->t('View'))->toString(),
      ]);
    }

    $form_state->setRedirect("view.{$entity->getEntityTypeId()}.list", ['cloud_context' => $entity->getCloudContext()]);
  }

}
